==> jc-1.4.0.tar.gz: soot/jimple/parser/node/ASpecialNonstaticInvoke.h <==
// public final class soot.jimple.parser.node.ASpecialNonstaticInvoke

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c6fe3dbae4224bda soot_jimple_parser_node_ASpecialNonstaticInvoke
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class d4ca50e4d96c30c8 soot_jimple_parser_node_PNonstaticInvoke

// header file dependencies
// @dep_header soot_jimple_parser_node_PNonstaticInvoke

#include "soot/jimple/parser/node/PNonstaticInvoke.h"

#ifndef _JC_soot_jimple_parser_node_ASpecialNonstaticInvoke_H_
#define _JC_soot_jimple_parser_node_ASpecialNonstaticInvoke_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TSpecialinvoke$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$sub_refs	_jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$sub_refs;
typedef struct _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$sub_nonrefs	_jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$refs	_jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$refs;
typedef struct _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$nonrefs	_jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$nonrefs;
typedef struct _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$object	_jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$object;

typedef const struct _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$vmethods	_jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$vmethods;
typedef const struct _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$vtable	_jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$vtable;
typedef const struct _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$vtype	_jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$object *);
extern void _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$method$_init$ecad6a569acaef12(_jc_env *, struct _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$object *, struct _jc_soot_jimple_parser_node_TSpecialinvoke$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$object *);
extern struct _jc_soot_jimple_parser_node_TSpecialinvoke$object *_jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$method$getSpecialinvoke$42f680958e616565(_jc_env *, struct _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$object *);
extern void _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$method$setSpecialinvoke$ba98ed8835ae6b30(_jc_env *, struct _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$object *, struct _jc_soot_jimple_parser_node_TSpecialinvoke$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$method_info$getSpecialinvoke$42f680958e616565;
extern _jc_method _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$method_info$setSpecialinvoke$ba98ed8835ae6b30;
extern _jc_method _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$object *);
	struct _jc_soot_jimple_parser_node_TSpecialinvoke$object	*(*getSpecialinvoke$42f680958e616565)(_jc_env *, struct _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setSpecialinvoke$ba98ed8835ae6b30)(_jc_env *, struct _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$object *, struct _jc_soot_jimple_parser_node_TSpecialinvoke$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PNonstaticInvoke$vmethods	soot_jimple_parser_node_PNonstaticInvoke;
	_jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$vmethods	soot_jimple_parser_node_ASpecialNonstaticInvoke;
};

// Vtype
struct _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$sub_refs {
	struct _jc_soot_jimple_parser_node_TSpecialinvoke$object	*__5fspecialinvoke__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$refs {
    _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$sub_refs	soot_jimple_parser_node_ASpecialNonstaticInvoke;
    _jc_soot_jimple_parser_node_PNonstaticInvoke$sub_refs	soot_jimple_parser_node_PNonstaticInvoke;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PNonstaticInvoke$sub_nonrefs	soot_jimple_parser_node_PNonstaticInvoke;
    _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$sub_nonrefs	soot_jimple_parser_node_ASpecialNonstaticInvoke;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$object {
	_jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$vtype	*vtype;
	_jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$vtype _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_ASpecialNonstaticInvoke, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$class_object;

#endif	/* _JC_soot_jimple_parser_node_ASpecialNonstaticInvoke_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/ASpecialNonstaticInvoke.h <==
// public final class soot.jimple.parser.node.ASpecialNonstaticInvoke

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class c6fe3dbae4224bda soot_jimple_parser_node_ASpecialNonstaticInvoke
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class d4ca50e4d96c30c8 soot_jimple_parser_node_PNonstaticInvoke

// header file dependencies
// @dep_header soot_jimple_parser_node_PNonstaticInvoke

#include "soot/jimple/parser/node/PNonstaticInvoke.h"

#ifndef _JC_soot_jimple_parser_node_ASpecialNonstaticInvoke_H_
#define _JC_soot_jimple_parser_node_ASpecialNonstaticInvoke_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TSpecialinvoke$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$sub_refs	_jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$sub_refs;
typedef struct _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$sub_nonrefs	_jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$refs	_jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$refs;
typedef struct _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$nonrefs	_jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$nonrefs;
typedef struct _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$object	_jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$object;

typedef const struct _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$vmethods	_jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$vmethods;
typedef const struct _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$vtable	_jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$vtable;
typedef const struct _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$vtype	_jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$method$_init$ecad6a569acaef12(_jc_env *, struct _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$object *, struct _jc_soot_jimple_parser_node_TSpecialinvoke$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_TSpecialinvoke$object *_jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$method$getSpecialinvoke$42f680958e616565(_jc_env *, struct _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$method$setSpecialinvoke$ba98ed8835ae6b30(_jc_env *, struct _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$object *, struct _jc_soot_jimple_parser_node_TSpecialinvoke$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$method_info$getSpecialinvoke$42f680958e616565;
extern _jc_method _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$method_info$setSpecialinvoke$ba98ed8835ae6b30;
extern _jc_method _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_TSpecialinvoke$object	*(*getSpecialinvoke$42f680958e616565)(_jc_env *, struct _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setSpecialinvoke$ba98ed8835ae6b30)(_jc_env *, struct _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$object *, struct _jc_soot_jimple_parser_node_TSpecialinvoke$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PNonstaticInvoke$vmethods	soot_jimple_parser_node_PNonstaticInvoke;
	_jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$vmethods	soot_jimple_parser_node_ASpecialNonstaticInvoke;
};

// Vtype
struct _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$sub_refs {
	struct _jc_soot_jimple_parser_node_TSpecialinvoke$object	*__5fspecialinvoke__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$refs {
    _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$sub_refs	soot_jimple_parser_node_ASpecialNonstaticInvoke;
    _jc_soot_jimple_parser_node_PNonstaticInvoke$sub_refs	soot_jimple_parser_node_PNonstaticInvoke;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PNonstaticInvoke$sub_nonrefs	soot_jimple_parser_node_PNonstaticInvoke;
    _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$sub_nonrefs	soot_jimple_parser_node_ASpecialNonstaticInvoke;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$object {
	_jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$vtype	*vtype;
	_jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$vtype _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_ASpecialNonstaticInvoke, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_ASpecialNonstaticInvoke$class_object;

#endif	/* _JC_soot_jimple_parser_node_ASpecialNonstaticInvoke_H_ */
